@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import matplotlib as mpl
 import matplotlib.pyplot as plt
+from matplotlib.markers import MarkerStyle
 
 from pymyplot.colors import get_color
 
@@ -12,7 +13,8 @@ px = 1 / plt.rcParams["figure.dpi"]
 # Overwrite matplotlib.pyplot to myplt so that can have a specific plot style when the preset (e.g. pymyplot.aip) is imported
 myplt = plt
 mympl = mpl
+mymarker = MarkerStyle
 
 
 __all__ = ["get_color"]
-__version__ = "0.0.2"
+__version__ = "0.1.0"
